@@ -1,4 +1,4 @@
-#' Variable selection with cross-validation
+#' Run search and performance evaluation with cross-validation
 #'
 #' Run the *search* part and the *evaluation* part for a projection predictive
 #' variable selection. The search part determines the solution path, i.e., the
@@ -33,29 +33,29 @@
 #'   this is known to bias the predictive performance estimates of the selected
 #'   submodels. However, setting this to `FALSE` can sometimes be useful because
 #'   comparing the results to the case where this argument is `TRUE` gives an
-#'   idea of how strongly the variable selection is (over-)fitted to the data
-#'   (the difference corresponds to the search degrees of freedom or the
-#'   effective number of parameters introduced by the search).
+#'   idea of how strongly the search is (over-)fitted to the data (the
+#'   difference corresponds to the search degrees of freedom or the effective
+#'   number of parameters introduced by the search).
 #' @param seed Pseudorandom number generation (PRNG) seed by which the same
 #'   results can be obtained again if needed. Passed to argument `seed` of
-#'   [set.seed()], but can also be `NA` to not call [set.seed()] at all. Here,
-#'   this seed is used for clustering the reference model's posterior draws (if
-#'   `!is.null(nclusters)` or `!is.null(nclusters_pred)`), for subsampling LOO
-#'   CV folds (if `nloo` is smaller than the number of observations), for
-#'   sampling the folds in K-fold CV, and for drawing new group-level effects
-#'   when predicting from a multilevel submodel (however, not yet in case of a
-#'   GAMM).
+#'   [set.seed()], but can also be `NA` to not call [set.seed()] at all. If not
+#'   `NA`, then the PRNG state is reset (to the state before calling
+#'   [cv_varsel()]) upon exiting [cv_varsel()]. Here, `seed` is used for
+#'   clustering the reference model's posterior draws (if `!is.null(nclusters)`
+#'   or `!is.null(nclusters_pred)`), for subsampling LOO CV folds (if `nloo` is
+#'   smaller than the number of observations), for sampling the folds in
+#'   \eqn{K}-fold CV, and for drawing new group-level effects when predicting
+#'   from a multilevel submodel (however, not yet in case of a GAMM).
 #'
 #' @inherit varsel details return
 #'
-#' @note The case `cv_method == "LOO" && !validate_search` constitutes an
-#'   exception where the search part is not cross-validated. In that case, the
-#'   evaluation part is based on a PSIS-LOO CV also for the submodels.
+#' @note If `validate_search` is `FALSE`, the search is not included in the CV
+#'   so that only a single full-data search is run.
 #'
-#'   For all PSIS-LOO CVs, \pkg{projpred} calls [loo::psis()] with `r_eff = NA`.
-#'   This is only a problem if there was extreme autocorrelation between the
-#'   MCMC iterations when the reference model was built. In those cases however,
-#'   the reference model should not have been used anyway, so we don't expect
+#'   For PSIS-LOO CV, \pkg{projpred} calls [loo::psis()] with `r_eff = NA`. This
+#'   is only a problem if there was extreme autocorrelation between the MCMC
+#'   iterations when the reference model was built. In those cases however, the
+#'   reference model should not have been used anyway, so we don't expect
 #'   \pkg{projpred}'s `r_eff = NA` to be a problem.
 #'
 #' @references
@@ -89,16 +89,16 @@
 #'   # example; this is not recommended in general):
 #'   fit <- rstanarm::stan_glm(
 #'     y ~ X1 + X2 + X3 + X4 + X5, family = gaussian(), data = dat_gauss,
-#'     QR = TRUE, chains = 2, iter = 500, refresh = 0, seed = 9876
+#'     QR = TRUE, chains = 2, iter = 1000, refresh = 0, seed = 9876
 #'   )
 #'
-#'   # Variable selection with cross-validation (with small values
-#'   # for `nterms_max`, `nclusters`, and `nclusters_pred`, but only for the
-#'   # sake of speed in this example; this is not recommended in general):
-#'   cvvs <- cv_varsel(fit, nterms_max = 3, nclusters = 5, nclusters_pred = 10,
-#'                     seed = 5555)
+#'   # Run cv_varsel() (with small values for `K`, `nterms_max`, `nclusters`,
+#'   # and `nclusters_pred`, but only for the sake of speed in this example;
+#'   # this is not recommended in general):
+#'   cvvs <- cv_varsel(fit, cv_method = "kfold", K = 2, nterms_max = 3,
+#'                     nclusters = 5, nclusters_pred = 10, seed = 5555)
 #'   # Now see, for example, `?print.vsel`, `?plot.vsel`, `?suggest_size.vsel`,
-#'   # and `?solution_terms.vsel` for possible post-processing functions.
+#'   # and `?ranking` for possible post-processing functions.
 #' }
 #'
 #' @export
@@ -134,16 +134,20 @@ cv_varsel.refmodel <- function(
     thresh = 1e-6,
     regul = 1e-4,
     validate_search = TRUE,
-    seed = sample.int(.Machine$integer.max, 1),
+    seed = NA,
     search_terms = NULL,
     ...
 ) {
-  # Set seed, but ensure the old RNG state is restored on exit:
   if (exists(".Random.seed", envir = .GlobalEnv)) {
     rng_state_old <- get(".Random.seed", envir = .GlobalEnv)
-    on.exit(assign(".Random.seed", rng_state_old, envir = .GlobalEnv))
   }
-  if (!is.na(seed)) set.seed(seed)
+  if (!is.na(seed)) {
+    # Set seed, but ensure the old RNG state is restored on exit:
+    if (exists(".Random.seed", envir = .GlobalEnv)) {
+      on.exit(assign(".Random.seed", rng_state_old, envir = .GlobalEnv))
+    }
+    set.seed(seed)
+  }
 
   refmodel <- object
   # Parse arguments which also exist in varsel():
@@ -201,24 +205,9 @@ cv_varsel.refmodel <- function(
     )
     verb_out("-----", verbose = verbose)
     ce_out <- rep(NA_real_, length(search_path_full_data$solution_terms) + 1L)
-
-    # Create `pct_solution_terms_cv`, a summary table of the fold-wise solution
-    # paths. For the column names (and therefore the order of the solution terms
-    # in the columns), the solution path from the full-data search is used. Note
-    # that the following code assumes that all CV folds have equal weight.
-    pct_solution_terms_cv <- cbind(
-      size = seq_len(ncol(sel_cv$solution_terms_cv)),
-      do.call(cbind, lapply(
-        setNames(nm = search_path_full_data$solution_terms),
-        function(soltrm_k) {
-          colMeans(sel_cv$solution_terms_cv == soltrm_k, na.rm = TRUE)
-        }
-      ))
-    )
   } else {
     search_path_full_data <- sel_cv$search_path
     ce_out <- sel_cv$ce
-    pct_solution_terms_cv <- NULL
   }
 
   # Defined here for `nobs_test` later:
@@ -240,7 +229,7 @@ cv_varsel.refmodel <- function(
               nobs_train = refmodel$nobs,
               search_path = search_path_full_data,
               solution_terms = search_path_full_data$solution_terms,
-              pct_solution_terms_cv,
+              solution_terms_cv = sel_cv$solution_terms_cv,
               ce = ce_out,
               type_test = cv_method,
               y_wobs_test,
@@ -255,7 +244,8 @@ cv_varsel.refmodel <- function(
               clust_used_search = search_path_full_data$p_sel$clust_used,
               clust_used_eval = refdist_eval_dummy$clust_used,
               nprjdraws_search = NCOL(search_path_full_data$p_sel$mu),
-              nprjdraws_eval = NCOL(refdist_eval_dummy$mu))
+              nprjdraws_eval = NCOL(refdist_eval_dummy$mu),
+              projpred_version = utils::packageVersion("projpred"))
   class(vs) <- "vsel"
   return(vs)
 }
@@ -959,7 +949,7 @@ get_kfold <- function(refmodel, K, verbose) {
                  "(using the fold-wise training data) ...")
       }
       nobs <- refmodel$nobs
-      folds <- cvfolds(nobs, K = K)
+      folds <- cv_folds(nobs, K = K, seed = sample.int(.Machine$integer.max, 1))
       cvfits <- refmodel$cvfun(folds)
       verb_out("-----", verbose = verbose)
     } else {
